@@ -1,8 +1,9 @@
 package
     DBIx::ParseDSN::Bar;
 
-use Moose;
+use Moo;
 extends "DBIx::ParseDSN::Default";
+use namespace::clean;
 
 sub i_am_also_a_custom_driver { return 1 }
 
