@@ -1,7 +1,8 @@
 package
     DBIx::ParseDSN::Foo;
 
-use Moose;
+use Moo;
+use namespace::clean;
 extends 'DBIx::ParseDSN::Default';
 
 sub i_am_a_custom_driver { return 1 }
